@@ -29,12 +29,18 @@ def clean(sid_file, pid_file, sid_pid, sids_dir, pids_dir):
     """
     for fn in (sid_file, pid_file, sid_pid):
         if os.path.exists(fn):
-            os.unlink(fn)
+            try:
+                os.unlink(fn)
+            except OSError:
+                pass
 
     for dn in (sids_dir, pids_dir):
         if os.path.isdir(dn):
             for filename in glob.glob(os.path.join(dn, "*.sid")):
-                os.unlink(filename)
+                try:
+                    os.unlink(filename)
+                except OSError:
+                    pass
 
 class CoreWsdl:
     # watch for process
@@ -126,7 +132,7 @@ def monitor(certbase, SID_FILE):
         time.sleep(60 * period)
 
 # check client's presence
-def sid_monitor(SID_FILE, SIDS_DIR):
+def sid_monitor(SID_FILE, SIDS_DIR, base_obj):
     # check interval
     period = 21
     while True:
@@ -155,23 +161,24 @@ def sid_monitor(SID_FILE, SIDS_DIR):
             for filename in sids:
                 # find file this session
                 sid_path = SIDS_DIR + "/%d.sid"%filename
-                if os.path.isfile(sid_path):
-                    with open(sid_path) as fd:
-                        # read information about session
-                        sid_inf = pickle.load(fd)
-                        # if number of missed inspections more 3
-                        if sid_inf[1] > 3:
-                            # flag client absence
-                            sid_inf[2] = 1
-                    fd.close()
+                with base_obj.sid_locker:
                     if os.path.isfile(sid_path):
-                        ft = open(sid_path, 'w')
-                        # add to digit missed inspections
-                        # client constantly nulls this value!
-                        if sid_inf[1] < 4:
-                            sid_inf[1] += 1
-                            pickle.dump(sid_inf, ft)
-                            ft.close()
+                        with open(sid_path) as fd:
+                            # read information about session
+                            sid_inf = pickle.load(fd)
+                            # if number of missed inspections more 3
+                            if sid_inf[1] > 3:
+                                # flag client absence
+                                sid_inf[2] = 1
+                        fd.close()
+                        if os.path.isfile(sid_path):
+                            ft = open(sid_path, 'w')
+                            # add to digit missed inspections
+                            # client constantly nulls this value!
+                            if sid_inf[1] < 4:
+                                sid_inf[1] += 1
+                                pickle.dump(sid_inf, ft)
+                                ft.close()
         except:
             pass
         # check period
