@@ -77,6 +77,7 @@ class Wsdl(WsdlBase):
                 normal=('cl_core_pkg_name',),
                 expert=('cl_core_pkg_category', 'cl_core_pkg_version',
                         'cl_core_pkg_slot', 'cl_core_pkg_path',
+                        'cl_core_arch_machine',
                         'cl_templates_locate',
                         'cl_core_pkg_system_set', 'cl_core_pkg_desktop_set',
                         'cl_core_pkg_root_set',
@@ -118,6 +119,7 @@ class Wsdl(WsdlBase):
                 normal=('cl_core_pkg_name',),
                 expert=('cl_core_pkg_category', 'cl_core_pkg_version',
                         'cl_core_pkg_slot', 'cl_core_pkg_path',
+                        'cl_core_arch_machine',
                         'cl_templates_locate','cl_verbose_set'),
                 next_label=_("Perform"))]},
         #
@@ -523,7 +525,7 @@ class Wsdl(WsdlBase):
         # заголовок метода 
         'title':__("Setup Variables"),
         # иконка для графической консоли
-        'image':'applications-versioncontrol',
+        'image':'applications-versioncontrol,text-x-preview',
         # метод в графической консоли
         'gui':True,
         # консольная команда
@@ -607,7 +609,7 @@ class Wsdl(WsdlBase):
         'groups':[
             lambda group:group(_("Custom action"),
                 normal=('ac_custom_name','cl_human_edit_set','cl_verbose_set'),
-                expert=('ur_core_login',
+                expert=('ur_core_login', 'cl_core_arch_machine',
                         'cl_templates_locate',
                         'cl_dispatch_conf'),
                 next_label=_("Perform"))]},
@@ -618,7 +620,7 @@ class Wsdl(WsdlBase):
         # идентификатор метода
         'method_name':"core_restart",
         # категория метода
-        'category':__('Update '),
+        'category':__('Utilities'),
         # заголовок метода 
         'title':__("Restart calculate-core"),
         # иконка для графической консоли
